#include <iostream>
#include <string>
#include <cstdio>
#include "fdstream.hh"

void popen_test(
  std::string const & command
) {
  // Executes a command writing its output to an Unix pipe; reads from
  // the pipe, writing every line on the standard output stream
  // prefixed by the string "> ".

  FILE * fp;

  if ((fp = popen(command.c_str(), "r")) == 0) {
    std::perror("popen");
  } else {
    fdistream in(fileno(fp));
    char      c;
    bool      bol;

    if (isatty(1)) {
      std::cout << "Output of the command \"" << command << "\":\n\n";
    }

    for (bol = true;   in.get(c);   bol = (c == '\n')) {
      if (bol) {
        std::cout.put('>');
        std::cout.put(' ');
      }
      std::cout.put(c);
    }

    if (isatty(1)) std::cout << std::endl;
    pclose(fp);
  }
}

int main(
  int    argc,
  char * argv[]
) {
  // Calls popen_test() for the commands given as program arguments

  while (--argc) {
    popen_test(*(++argv));
  }
  return 0;
}
